ElementInteractionsEnabled class

Enable autocapture ElementInteractions.

Enables click tracking with the Flutter-aware ElementInteractionsOptions.defaultCssSelectorAllowlist, so clicks on Flutter web widgets are captured. Use ElementInteractionsOptions if you need to customize the allowlist or the other options.

Example usage:

var analytics = Amplitude(
    Configuration(
        apiKey: 'your_api_key',
        autocapture: AutocaptureOptions(
            elementInteractions: ElementInteractionsEnabled(),
        ),
    )
);
Inheritance

Constructors

ElementInteractionsEnabled()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited