Identify class

Constructors

Identify()

Properties

hashCode → int
The hash code for this object.
no setterinherited
properties ↔ Map<String, dynamic>
getter/setter pair
propertySet ↔ Set<String>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(String property, dynamic value) → Identify
append(String property, dynamic value) → Identify
clearAll() → Identify
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preInsert(String property, dynamic value) → Identify
prepend(String property, dynamic value) → Identify
remove(String property, dynamic value) → Identify
set(String property, dynamic value) → Identify
setOnce(String property, dynamic value) → Identify
toString() → String
A string representation of this object.
inherited
unset(String property) → Identify

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

UNSET_VALUE → const String