Plan class

Used for Ampli to represent an Amplitude tracking plan

Constructors

Plan({String? branch, String? source, String? version, String? versionId})

Properties

branch ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source ↔ String?
getter/setter pair
version ↔ String?
getter/setter pair
versionId ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited