AutocaptureOptions class
Options for the autocapture feature.
Flutter supports the autocapture options exposed by this class. The underlying Web, iOS, and Android SDKs may support additional autocapture options that are not exposed by this Flutter SDK.
For platform behavior details, see: Web, iOS, Android.
Example usage:
var analytics = Amplitude(
Configuration(
apiKey: 'your_api_key',
autocapture: AutocaptureOptions(
attribution: AttributionOptions(),
sessions: true,
pageViews: PageViewsOptions(),
appLifecycles: true,
deepLinks: true,
),
)
);
- Inheritance
-
- Object
- Autocapture
- AutocaptureOptions
Constructors
- AutocaptureOptions({Attribution attribution = const AttributionOptions(), bool sessions = true, dynamic pageViews = const PageViewsOptions(), bool appLifecycles = false, bool deepLinks = false})
-
const
Properties
- appLifecycles → bool
-
Mobile (iOS and Android) specific
final
- attribution → Attribution
-
Web specific
final
- deepLinks → bool
-
Mobile (Android) specific
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pageViews → dynamic
-
Web specific
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessions → bool
-
Cross-platform
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited