actionClickAllowlist property
Web specific
List of CSS selectors whose clicks should also be attributed to a matching ancestor element (useful when clicks land on a child of the tracked element).
Implementation
final List<String>? actionClickAllowlist;